//
//  AlbumLayer.m
//  Photos
//
//  Created by Jun Nishimura on 6/26/12.
//  Copyright (c) 2012 Jun Nishimura. All rights reserved.
//

#import "AlbumLayer.h"

@implementation AlbumLayer

@synthesize index = _index;
@synthesize album;

+ (AlbumLayer*)layerWithIndex:(NSUInteger)index album:(ALAssetsGroup*)album
{
    AlbumLayer* layer = [AlbumLayer layer];
    [layer setBorderColor:[[UIColor lightGrayColor] CGColor]];
    [layer setBorderWidth:1.0];
    [layer setIndex:index];
    [layer setAlbum:album];
    [layer updateFrame];

    CGRect bounds = layer.bounds;
    bounds.size.width *= 0.5;
    CALayer* image = [CALayer layer];
    [image setFrame:bounds];
    [image setContentsGravity:kCAGravityResizeAspectFill];
    [image setMasksToBounds:YES];
    [image setContents:(id)[album posterImage]];
    [layer addSublayer:image];

    CAGradientLayer* gradient = [CAGradientLayer layer];
    [gradient setFrame:layer.bounds];
    [gradient setLocations:[NSArray arrayWithObjects:
        [NSNumber numberWithFloat:0.0],
        [NSNumber numberWithFloat:1.0], nil]];
    [gradient setColors:[NSArray arrayWithObjects:
        (id)[UIColor colorWithWhite:0.0 alpha:1.0].CGColor,
        (id)[UIColor colorWithWhite:0.0 alpha:0.0].CGColor, nil]];
    [gradient setStartPoint:CGPointMake( 0.5, 0.5 )];
    [gradient setEndPoint:CGPointMake( 0.0, 0.5 )];
    [layer addSublayer:gradient];

    CATextLayer* text = [CATextLayer layer];
    NSString* albumText = [NSString stringWithFormat:@"%@",
        [album valueForProperty:ALAssetsGroupPropertyName]];
    bounds = layer.bounds;
    bounds.origin.y += 16;
    bounds.size.width -= 16;
    bounds.size.height -= 32;
    [text setContentsScale:[[UIScreen mainScreen] scale]];
    [text setFrame:bounds];
    [text setFontSize:20];
    [text setForegroundColor:[[UIColor whiteColor] CGColor]];
    [text setAlignmentMode:kCAAlignmentRight];
    [text setTruncationMode:kCATruncationEnd];
    [text setWrapped:YES];
    [text setString:albumText];
    [layer addSublayer:text];

    return layer;
}

+ (CGRect)getFrame:(NSUInteger)nalbums
{
    CGFloat height = 100;
    CGFloat inset = 10;

    return CGRectMake( 0, 0, 320, nalbums * ( height + inset ) + inset );
}

- (void)updateFrame
{
    CGFloat height = 100;
    CGFloat inset = 10;

    [self setFrame:CGRectMake( inset, self.index * ( height + inset ) + inset, 320 - 2 * inset, height )];
}


@end
