//
//  AlbumViewController.m
//  Photos
//
//  Created by Jun Nishimura on 6/26/12.
//  Copyright (c) 2012 Jun Nishimura. All rights reserved.
//

#import "AlbumViewController.h"

#import "AppDelegate.h"
#import "AlbumLayer.h"

@interface AlbumViewController ()

@end

@implementation AlbumViewController

@synthesize albumScrollView, albumView;
@synthesize albums;

- (void)reloadAlbums
{
    for ( CALayer* layer in albums )
    {
        for ( CALayer* sublayer in layer.sublayers )
        {
            [sublayer removeFromSuperlayer];
        }
        [layer removeFromSuperlayer];
    }
    [albums removeAllObjects];

    ALAssetsLibraryGroupsEnumerationResultsBlock resultBlock = ^ ( ALAssetsGroup* assetsGroup, BOOL* stop )
    {
        if ( assetsGroup )
        {
            AlbumLayer* layer = [AlbumLayer layerWithIndex:albums.count album:assetsGroup];
            [albumView.layer addSublayer:layer];
            [albums addObject:layer];
        }
        else
        {
            [albumView setFrame:[AlbumLayer getFrame:albums.count]];
            [albumScrollView setContentSize:albumView.bounds.size];
            [albumScrollView setContentOffset:CGPointZero];
        }
    };

    ALAssetsLibrary* library = [[AppDelegate delegate] assetsLibrary];
    [library enumerateGroupsWithTypes:ALAssetsGroupAll usingBlock:resultBlock failureBlock:^ ( NSError* error )
        {
            NSLog( @"%@", error );
        }
    ];

}

- (IBAction)tapGestureEvent:(id)sender
{
    CGPoint point = [(UITapGestureRecognizer*)sender locationInView:albumView];
    CALayer* layer = [albumView.layer hitTest:point];
    if ( ![layer isEqual:albumView.layer] && layer )
    {
        if ( [layer isMemberOfClass:[CAGradientLayer class]] ||
             [layer isMemberOfClass:[CATextLayer class]] )
        {
            CALayer* superLayer = [layer superlayer];
            if ( [superLayer isMemberOfClass:[AlbumLayer class]] )
            {
                [[AppDelegate delegate] setCurrentAlbum:[(AlbumLayer*)superLayer album]];
                [self performSegueWithIdentifier:@"Push" sender:self];
            }
        }
    }
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    albums = [[NSMutableArray alloc] init];

    albumView = [[UIView alloc] init];
    [albumView setBackgroundColor:[UIColor clearColor]];
    [albumScrollView addSubview:albumView];

    [self reloadAlbums];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return ( interfaceOrientation == UIInterfaceOrientationPortrait );
}

@end
